User: dsundstrom
Date: 02/04/13 18:06:16
Modified: src/main/org/jboss/ejb EntityPersistenceManager.java
Log:
Added new postCreateEntity method which is used to call the ejbPostCreate
method in the entity implementation class.
Revision Changes Path
1.14 +20 -4 jboss/src/main/org/jboss/ejb/EntityPersistenceManager.java
Index: EntityPersistenceManager.java
===================================================================
RCS file: /cvsroot/jboss/jboss/src/main/org/jboss/ejb/EntityPersistenceManager.java,v
retrieving revision 1.13
retrieving revision 1.14
diff -u -r1.13 -r1.14
--- EntityPersistenceManager.java 24 Mar 2002 21:48:06 -0000 1.13
+++ EntityPersistenceManager.java 14 Apr 2002 01:06:16 -0000 1.14
@@ -25,10 +25,10 @@
* @see EntityContainer
*
* @author <a href="mailto:[EMAIL PROTECTED]">Rickard �berg</a>
- * @version $Revision: 1.13 $
+ * @author <a href="mailto:[EMAIL PROTECTED]">Dain Sundstrom</a>
+ * @version $Revision: 1.14 $
*/
-public interface EntityPersistenceManager
- extends ContainerPlugin//, StatisticsProvider
+public interface EntityPersistenceManager extends ContainerPlugin
{
/**
* Returns a new instance of the bean class or a subclass of the bean class.
@@ -39,7 +39,7 @@
/**
* This method is called whenever an entity is to be created. The
* persistence manager is responsible for calling the ejbCreate methods
* on the instance and to handle the results properly wrt the persistent
* store.
*
@@ -49,6 +49,22 @@
* @param instance the instance being used for this create call
*/
void createEntity(Method m,
+ Object[] args,
+ EntityEnterpriseContext instance)
+ throws Exception;
+
+ /**
+ * This method is called whenever an entity is to be created. The
+ * persistence manager is responsible for calling the ejbPostCreate method
+ * on the instance and to handle the results properly wrt the persistent
+ * store.
+ *
+ * @param m the create method in the home interface that was
+ * called
+ * @param args any create parameters
+ * @param instance the instance being used for this create call
+ */
+ void postCreateEntity(Method m,
Object[] args,
EntityEnterpriseContext instance)
throws Exception;
@@ -39,7 +39,7 @@
/**
* This method is called whenever an entity is to be created. The
- * persistence manager is responsible for calling the ejbCreate methods
+ * persistence manager is responsible for calling the ejbCreate method
* on the instance and to handle the results properly wrt the persistent
* store.
_______________________________________________
Jboss-development mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/jboss-development